<?php
/*
Plugin Name: Ada Active Blogs
Plugin URI: http://adadaa.com/
Description: Adds a sidebar widget to let you display active blogs by post count from WordPressMU.
Author: CAPitalZ
Version: 0.1
Author URI: http://adadaa.com/
*/

// Put functions into one big function we'll call at the plugins_loaded
// action. This ensures that all required plugin functions are defined.
function ada_active_blogs_init() {
 
$widget_title = "Active Blogs";	// Change this to name the widget

	// Check for the required plugin functions. This will prevent fatal
	// errors occurring when you deactivate the dynamic-sidebar plugin.
	if ( !function_exists('get_most_active_blogs') || !function_exists('get_blog_details'))
		return;

	// This is the function that gets the values from sidbar widgets and
	// displays it on the output page.
	function widget_aablogs($args) {
		
		// $args is an array of strings that help widgets to conform to
		// the active theme: before_widget, before_title, after_widget,
		// and after_title are the array keys. Default tags: li and h2.
		extract($args);

		// Each widget can store its own options. We keep strings here.
		$options = get_option('widget_aablogs');
		$title = $options['title'];
		$limit = abs($options['limit']);

		// hard coded values
		$begin_wrap = '<ul>';
		$end_wrap = '</ul>';		
		$title_begin_wrap = '<li>';	
		$title_end_wrap = '</li>';

		// These lines generate our output. Widgets can be very complex
		// but as you can see here, they can also be very, very simple.
		echo $before_widget . $before_title . $title . $after_title;

	    echo $begin_wrap;

		// Get the most active blogs from a WPMU built-in function
	    $most_active = get_most_active_blogs( $limit, false );
	    if( is_array( $most_active ) ) {
			while( list( $key, $details ) = each( $most_active ) ) { 
			 	
				//get blog details from a WPMU built-in function
		 	    $blog_details = get_blog_details($details[ 'blog_id' ],true);
		
			    $class = ('alternate' == $class) ? '' : 'alternate';
			    print  $title_begin_wrap. "<a href='" . $blog_details->siteurl . "'>". $blog_details->blogname . "</a> (" . $blog_details->post_count . ")". $title_end_wrap;
			}
    	}
    
    	echo $end_wrap;    
		echo $after_widget;

	}

	// This is the function that outputs the form in the "Sidbar Widgets" page and
	// to let the users edit the widget's options.
	function widget_aablogs_control() {
	 global $widget_title;

		// Get our options and see if we're handling a form submission.
		$options = get_option('widget_aablogs');
		if ( !is_array($options) )
			//initial values
			$options = array('title'=>'Active Blogs', 'limit'=>'10');


		if ( $_POST['aablogs-submit'] ) {

			// Remember to sanitize and format use input appropriately.
			$options['title'] = strip_tags(stripslashes($_POST['aablogs-title']));
			$options['limit'] = strip_tags(stripslashes($_POST['aablogs-limit']));
			update_option('widget_aablogs', $options);
		}

		// Be sure you format your options to be valid HTML attributes.
		$title = htmlspecialchars($options['title'], ENT_QUOTES);
		$limit = htmlspecialchars($options['limit'], ENT_QUOTES);

		// Here is our little form segment. Notice that we don't need a
		// complete form. This will be embedded into the existing form.
		echo '<p style="text-align:right;"><label for="aablogs-title">' . __('Title:') . ' <input style="width: 200px;" id="aablogs-title" name="aablogs-title" type="text" value="'.$title.'" /></label></p>';

		echo '<p style="text-align:right;"><label for="aablogs-limit">' . __('Limit:', 'widgets') . ' <input style="width: 200px;" id="aablogs-limit" name="aablogs-limit" type="text" value="'.$limit.'" /></label></p>';
		/* If commented above line and uncommented this code,
			widget will display a pull down menu for limit with 1 to 10 options

		echo '<p style="text-align:right;"><label for="aablogs-limit">' . __('Limit:', 'widgets') . ' <select style="width: 200px;" id="aablogs-limit" name="aablogs-limit">';
			echo '<option value="1" ';
			if($limit=='1') { echo 'selected="selected"'; }
			echo '>1</option><option value="2" ';
		    if($limit=='2') { echo 'selected="selected"';}
		    echo '>2</option><option value="3" ';
		    if($limit=='3') { echo 'selected="selected"';}
			echo '>3</option><option value="4" ';
			if($limit=='4') { echo 'selected="selected"';}
			echo '>4</option><option value="5" ';
			if($limit=='5') { echo 'selected="selected"';}
			echo '>5</option><option value="6" ';
			if($limit=='6') { echo 'selected="selected"';}
			echo '>6</option><option value="7" ';
			if($limit=='7') { echo 'selected="selected"';}
			echo '>7</option><option value="8" ';
			if($limit=='8') { echo 'selected="selected"';}
			echo '>8</option><option value="9" ';
			if($limit=='9') { echo 'selected="selected"';}
			echo '>9</option><option value="10" ';
			if($limit=='10') { echo 'selected="selected"';}
			echo '>10</option></select></label></p>';
		*/
	
		echo '<input type="hidden" id="aablogs-submit" name="aablogs-submit" value="1" />';
	}
	
	// This registers our widget so it appears with the other available
	// widgets and can be dragged and dropped into any active sidebars.
	register_sidebar_widget(array($widget_title, 'widgets'), 'widget_aablogs');

	// This registers our optional widget control form. Because of this
	// our widget will have a button that reveals a 300x100 pixel form.
	register_widget_control(array($widget_title, 'widgets'), 'widget_aablogs_control', 300, 100);
}

// Run our code later in case this loads prior to any required plugins.
add_action('widgets_init', 'ada_active_blogs_init');

?>