<?php
/*
Plugin Name: Ada New Blogs
Plugin URI: http://adadaa.com/
Description: Adds a sidebar widget to let you display new blogs from WordPressMU.
Author: CAPitalZ
Version: 0.1
Author URI: http://adadaa.com/
*/

// Put functions into one big function we'll call at the plugins_loaded
// action. This ensures that all required plugin functions are defined.
function ada_new_blogs_init() {
 
  $widget_title = "New Blogs";	// Change this to name the widget

	// Check for the required plugin functions. This will prevent fatal
	// errors occurring when you deactivate the dynamic-sidebar plugin.
	// This widget depends on List-All pluggin by Andrew Billits
	if ( !function_exists('list_all_wpmu_blogs') )
		return;

	// This is the function that gets the values from sidbar widgets and
	// displays it on the output page.
	function widget_anblogs($args) {
		
		// $args is an array of strings that help widgets to conform to
		// the active theme: before_widget, before_title, after_widget,
		// and after_title are the array keys. Default tags: li and h2.
		extract($args);

		// Each widget can store its own options. We keep strings here.
		$options = get_option('widget_anblogs');
		$title = $options['title'];
		$limit = abs($options['limit']);
		$display = $options['display'];
				
		//$order = $options['order'];
		// hard coded values
		$order = 'last_created';
		$begin_wrap = '<li>';
		$end_wrap = '</li>';

		// These lines generate our output. Widgets can be very complex
		// but as you can see here, they can also be very, very simple.
		echo $before_widget . $before_title . $title . $after_title;

		echo "<ul>\n";
		list_all_wpmu_blogs($limit, $display, $begin_wrap , $end_wrap, $order);
		echo "</ul>\n";
		echo $after_widget;

	}

	// This is the function that outputs the form in the "Sidbar Widgets" page and
	// to let the users edit the widget's options.
	function widget_anblogs_control() {

		// Get our options and see if we're handling a form submission.
		$options = get_option('widget_anblogs');
		if ( !is_array($options) )
			//initial values
			$options = array('title'=>'New Blogs', 'limit'=>'10', 'display'=>'name');


		if ( $_POST['anblogs-submit'] ) {

			// Remember to sanitize and format use input appropriately.
			$options['title'] = strip_tags(stripslashes($_POST['anblogs-title']));
			$options['limit'] = strip_tags(stripslashes($_POST['anblogs-limit']));
			$options['display'] = strip_tags(stripslashes($_POST['anblogs-display']));
			//$options['order'] = strip_tags(stripslashes($_POST['anblogs-order']));
			update_option('widget_anblogs', $options);
		}

		// Be sure you format your options to be valid HTML attributes.
		$title = htmlspecialchars($options['title'], ENT_QUOTES);
		$limit = htmlspecialchars($options['limit'], ENT_QUOTES);
		$display = htmlspecialchars($options['display'], ENT_QUOTES);
		//$order = htmlspecialchars($options['order'], ENT_QUOTES);
		
		// Here is our little form segment. Notice that we don't need a
		// complete form. This will be embedded into the existing form.
		echo '<p style="text-align:right;"><label for="anblogs-title">' . __('Title:') . ' <input style="width: 200px;" id="anblogs-title" name="anblogs-title" type="text" value="'.$title.'" /></label></p>';
		echo '<p style="text-align:right;"><label for="anblogs-limit">' . __('Limit:', 'widgets') . ' <input style="width: 200px;" id="anblogs-limit" name="anblogs-limit" type="text" value="'.$limit.'" /></label></p>';

		echo '<p style="text-align:right;"><label for="anblogs-display">' . __('Display:', 'widgets') . ' <select style="width: 100px;" id="anblogs-display" name="anblogs-display">';
			echo '<option value="name" ';
			if($display=='name') { echo 'selected="selected"';}
			echo '>Name</option><option value="url"';
			if($display=='url') { echo 'selected="selected"';}
			echo '>URL</option></select></label></p>';			

		//echo '<p style="text-align:right;"><label for="anblogs-order">' . __('Order [updated, first_created, last_created]:', 'widgets') . ' <input style="width: 100px;" id="anblogs-order" name="anblogs-order" type="text" value="'.$order.'" /></label></p>';

		echo '<input type="hidden" id="anblogs-submit" name="anblogs-submit" value="1" />';
	}
	
	// This registers our widget so it appears with the other available
	// widgets and can be dragged and dropped into any active sidebars.
	register_sidebar_widget(array($widget_title, 'widgets'), 'widget_anblogs');

	// This registers our optional widget control form. Because of this
	// our widget will have a button that reveals a 300x100 pixel form.
	register_widget_control(array($widget_title, 'widgets'), 'widget_anblogs_control', 300, 150);
}

// Run our code later in case this loads prior to any required plugins.
add_action('widgets_init', 'ada_new_blogs_init');

?>